@@ -27,6 +27,7 @@ class Command(BaseCommand):
     Create a new django migration with support for fixing conflicts.
     """
 
+    help = "Creates new migration(s) for apps and fix conflicts."
     success_msg = "Successfully fixed migrations."
 
     def __init__(self, *args, repo=None, **kwargs):
@@ -103,7 +104,7 @@ class Command(BaseCommand):
                     if self.verbosity >= 2:
                         self.stdout.write("Retrieving the current branch...")
 
-                    current_branch = self.repo.head.ref.name
+                    current_branch = self.repo.active_branch.name
 
                     if self.repo.is_dirty():  # pragma: no cover
                         raise CommandError(
